const gulp = require('gulp'),
    git = require('gulp-git'),
    bump = require('gulp-bump'),
    runSequence = require('run-sequence'),
    log = require('fancy-log'),
    zip = require('gulp-zip');

// To get fresh version and avoid cached result
let getPackageJson = () => require('./package.json');

/** ===============
 *  Bump
 *  ===============
 */
gulp.task('bump', function () {
    runSequence('bump:patch-task', 'bumpCommit', 'gitTag');
});
gulp.task('bump:patch', function () {
    runSequence('bump:patch-task', 'bumpCommit', 'gitTag');
});
gulp.task('bump:hotfix', function () {
    runSequence('bump:patch-task', 'bumpCommit', 'gitTag');
});
gulp.task('bump:patch-task', function () {
    return bumpApplication('patch');
});

gulp.task('bump:minor', function () {
    runSequence('bump:minor-task', 'bumpCommit', 'gitTag');
});
gulp.task('bump:minor-task', function () {
    return bumpApplication('minor');
});

gulp.task('bump:major', function () {
    runSequence('bump:major-task', 'bumpCommit', 'gitTag');
});
gulp.task('bump:major-task', function () {
    return bumpApplication('major');
});

function bumpApplication(type) {
    type = type === 'minor' || type === 'major' ? type : 'patch';

    return gulp.src([
        'package.json',
        'package-lock.json',
        'composer.json'
    ])
        .pipe(bump({type: type}).on('error', log))
        .pipe(gulp.dest('./'));
}


gulp.task('bumpCommit', function () {
    return gulp.src([
        'package.json',
        'package-lock.json',
        'composer.json'
    ])
        .pipe(git.add())
        .pipe(git.commit('Release v' + getPackageJson().version))
        .pipe(gulp.dest('./'));
});

gulp.task('gitTag', function () {
    return git.tag(getPackageJson().version, 'Release v' + getPackageJson().version, function (err) {
        if (err) throw err;
    });
});

gulp.task('dist', function () {
    return gulp.src([
        './**/*',
        '!./node_modules',
        '!./node_modules/**',
        '!./vendor',
        '!./vendor/**',
        '!./dist',
        '!./dist/**',
    ])
        .pipe(zip(getPackageJson().vendor + '-' + getPackageJson().name + '-' + getPackageJson().version + '.zip'))
        .pipe(gulp.dest('dist'));
});

