<?php
declare(strict_types=1);

/**
 * Support: for detecting devices
 */

namespace Infomaker\Everyware\Support;

use InvalidArgumentException;

/**
 * Device
 *
 * @link    http://infomaker.se
 * @package Infomaker\Everyware\Support
 * @since   Infomaker\Everyware\Support\Device 0.1
 */
class Device
{

    public const DESKTOP = 'desktop';
    public const TABLET = 'tablet';
    public const MOBILE = 'mobile';

    protected static $valid_devices = ['desktop', 'tablet', 'mobile'];

    /**
     * Contains the device currently being used
     *
     * @var string
     */
    protected static $currentDevice;

    /**
     * Retrieve current device used
     *
     * @return string
     */
    public static function currentDevice(): string
    {

        if (static::$currentDevice === null) {
            static::setDevice($_SERVER['EVERY_DEVICE'] ?? self::DESKTOP);
        }

        return static::$currentDevice;
    }

    /**
     * Determine if device is mobile phone
     *
     * @return bool
     */
    public static function isMobile(): bool
    {
        return static::currentDevice() === self::MOBILE;
    }

    /**
     * Determine if device is desktop
     *
     * @return bool
     */
    public static function isDesktop(): bool
    {
        return static::currentDevice() === self::DESKTOP;
    }

    /**
     * Determine if device tablet
     *
     * @return bool
     */
    public static function isTablet(): bool
    {
        return static::currentDevice() === self::TABLET;
    }

    /**
     * Set the current device
     *
     * @param string $device
     *
     * @return void
     */
    public static function setDevice($device): void
    {
        if ( ! \in_array($device, static::$valid_devices, true)) {
            throw new InvalidArgumentException('Invalid device given');
        }

        static::$currentDevice = $device;
    }
}
