<?php
/**
 * Storage handler: for cache-handling by using Wordpress transient
 */

namespace Infomaker\Everyware\Support\Storage;


use Infomaker\Everyware\Support\Interfaces\Storage\WpTransientInterface;

/**
 * Cache
 *
 * @link    http://infomaker.se
 * @package Infomaker\ProjectPlugin\Storage
 * @since   Infomaker\ProjectPlugin\Storage\Cache 0.1
 */
class Cache implements WpTransientInterface
{

    /**
     * Cache data
     *
     * @see   set_transient()
     *
     * @param string $name
     * @param mixed  $value
     * @param int    $expiration
     *
     * @return bool
     */
    public static function set($name, $value, $expiration = 0)
    {
        return set_transient($name, $value, $expiration);
    }

    /**
     * Cache data globally
     *
     * @see   set_site_transient()
     *
     * @param string $name
     * @param mixed  $value
     * @param int    $expiration
     *
     * @return bool
     */
    public static function setGlobal($name, $value, $expiration = 0)
    {
        return set_site_transient($name, $value, $expiration);
    }

    /**
     * Get cached data
     *
     * @see   get_transient()
     *
     * @param string $name
     * @param mixed  $default
     *
     * @return mixed
     */
    public static function get($name, $default = false)
    {
        if (($value = get_transient($name)) !== false) {
            return $value;
        }

        return $default;
    }

    /**
     * Get globally cached data
     *
     * @see   get_site_transient()
     *
     * @param string $name
     * @param mixed  $default
     *
     * @return mixed
     */
    public static function getGlobal($name, $default = false)
    {
        if (($value = get_site_transient($name)) !== false) {
            return $value;
        }

        return $default;
    }

    /**
     * Remove cached data
     *
     * @see   delete_transient()
     *
     * @param string $name
     *
     * @return bool
     */
    public static function remove($name)
    {
        return delete_transient($name);
    }

    /**
     * Remove globally cached data
     *
     * @see   delete_site_transient()
     *
     * @param string $name
     *
     * @return bool
     */
    public static function removeGlobal($name)
    {
        return delete_site_transient($name);
    }
}
